# harrier

[![CI](https://github.com/samuelcolvin/harrier/workflows/CI/badge.svg?event=push)](https://github.com/samuelcolvin/harrier/actions?query=event%3Apush+branch%3Amaster+workflow%3ACI)
[![Coverage](https://codecov.io/gh/samuelcolvin/harrier/branch/master/graph/badge.svg)](https://codecov.io/gh/samuelcolvin/harrier)
[![pypi](https://img.shields.io/pypi/v/harrier.svg)](https://pypi.python.org/pypi/harrier)
[![versions](https://img.shields.io/pypi/pyversions/harrier.svg)](https://github.com/samuelcolvin/harrier)
[![license](https://img.shields.io/github/license/samuelcolvin/harrier.svg)](https://github.com/samuelcolvin/harrier/blob/master/LICENSE)

A better static site generator.

See [documentation](https://harrier.helpmanual.io/) for more details.
